FileFormats-medimage-fsl
========================

.. image:: https://github.com/nipype/pydra-fsl/actions/workflows/ci-cd.yml/badge.svg
    :target: https://github.com/nipype/pydra-fsl/actions/workflows/ci-cd.yml

This is an extension module of the `fileformats <https://github.com/ArcanaFramework/fileformats>`__
package for defining file formats that are specific to the CHANGME software toolkit.


Quick Installation
------------------

This extension can be installed for Python 3 using *pip*::

    $ pip3 install fileformats-medimage-fsl

This will install the format extensions and dependent base packages.

License
-------

This work is licensed under a
`Creative Commons Attribution 4.0 International License <http://creativecommons.org/licenses/by/4.0/>`_

.. image:: https://i.creativecommons.org/l/by/4.0/88x31.png
  :target: http://creativecommons.org/licenses/by/4.0/
  :alt: Creative Commons Attribution 4.0 International License
